# Form Filler

Generate appropriate form values based on the user information provided.

## User Info
{user_info}

## Form Fields
{field_descriptions}

## Instructions

For each form field, generate an appropriate value based on:
- The field type (text, email, password, etc.)
- The field label and name
- Whether it's required
- The user info provided

Return a dictionary with field names as keys and appropriate values.
